@@ -1,14 +1,14 @@
 package App::CreateSparseFile;
 
-our $DATE = '2014-12-05'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2014-12-11'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
 use File::MoreUtil qw(file_exists);
-use SHARYANTO::Text::Prompt qw(confirm);
+use IO::Prompt::I18N qw(confirm);
 
 our %SPEC;
 
@@ -99,7 +99,7 @@ sub create_sparse_file {
     if (file_exists $fname) {
         if ($interactive) {
             return [200, "Cancelled"]
-                unless confirm "Confirm override existing file (y/n)?";
+                unless confirm "Confirm override existing file";
         } else {
             return [409, "File already exists"] unless $args{override};
         }
@@ -108,7 +108,7 @@ sub create_sparse_file {
         if ($interactive) {
             my $s = $suffix ? "$num ($size)" : $num;
             return [200, "Cancelled"]
-                unless confirm "Confirm create '$fname' with size $s (y/n)?";
+                unless confirm "Confirm create '$fname' with size $s";
         }
     }
 
@@ -135,7 +135,7 @@ App::CreateSparseFile - Create sparse file
 
 =head1 VERSION
 
-This document describes version 0.02 of App::CreateSparseFile (from Perl distribution App-CreateSparseFile), released on 2014-12-05.
+This document describes version 0.03 of App::CreateSparseFile (from Perl distribution App-CreateSparseFile), released on 2014-12-11.
 
 =head1 SYNOPSIS
 
